@@ -1,6 +1,6 @@
 from swarms.artifacts.base_artifact import BaseArtifact
 from swarms.artifacts.text_artifact import TextArtifact
-from swarms.artifacts.artifact_base import Artifact
+from swarms.artifacts.main_artifact import Artifact
 
 __all__ = [
     "BaseArtifact",
