@@ -1,10 +1,15 @@
+import os
+from dotenv import load_dotenv
 from loguru import logger
 
+load_dotenv()
+
+WORKSPACE_DIR = os.getenv("WORKSPACE_DIR")
+
 logger.add(
-    "swarms.log",
+    os.path.join(WORKSPACE_DIR, "swarms.log"),
     level="INFO",
     colorize=True,
-    format="<green>{time}</green> <level>{message}</level>",
     backtrace=True,
     diagnose=True,
 )
@@ -12,10 +17,9 @@ logger.add(
 
 def loguru_logger(file_path: str = "swarms.log"):
     return logger.add(
-        file_path,
+        os.path.join(WORKSPACE_DIR, file_path),
         level="INFO",
         colorize=True,
-        format="<green>{time}</green> <level>{message}</level>",
         backtrace=True,
         diagnose=True,
     )
